pub struct EventListenerRegisteredEvent {
pub item: ObjectRefOwned,
pub registered_event: EventListeners,
}Expand description
An event that is emitted by the regostry daemon to signal that an event has been registered to listen for.
Fields
item: ObjectRefOwnedThe ObjectRef the event applies to.
registered_event: EventListenersA list of events that have been registered via the registry interface.
See atspi-connection.